fnss.topologies.simplemodels.ring_topology — FNSS 0.1.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.0 documentation »
- API Reference »
- Functions »

# fnss.topologies.simplemodels.ring_topology

`ring_topology`(n)

  Return a ring topology of n nodes

  Parameters : | n : int The number of nodes
  Returns : | topology : A Topology object

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.0 documentation »
- API Reference »
- Functions »